@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -23,26 +23,14 @@ Increase less between tries
 
 /* uses PRIVATE interface */
 #define FDP_PRIVATE 1
-
 #include <fdpgen/xlayout.h>
 #include <neatogen/adjust.h>
 #include <fdpgen/dbg.h>
-#include <ctype.h>
 #include <math.h>
-
-/* Use bbox based force function */
-/* #define MS */
-/* Use alternate force function */
-/* #define ALT      */
-/* Add repulsive force even if nodes don't overlap */
-/* #define ORIG      */
-#define BOX	/* Use bbox to determine overlap, else use circles */
+#include <util/gv_ctype.h>
 
 #define DFLT_overlap   "9:prism"    /* default overlap value */
 
-#define WD2(n) (X_marg.doAdd ? (ND_width(n)/2.0 + X_marg.x): ND_width(n)*X_marg.x/2.0)
-#define HT2(n) (X_marg.doAdd ? (ND_height(n)/2.0 + X_marg.y): ND_height(n)*X_marg.y/2.0)
-
 static xparams xParams = {
     60,				/* numIters */
     0.0,			/* T0 */
@@ -50,10 +38,15 @@ static xparams xParams = {
     1.5,			/* C */
     0				/* loopcnt */
 };
-static double K2;
 static expand_t X_marg;
-static double X_nonov;
-static double X_ov;
+
+static double WD2(Agnode_t *n) {
+  return X_marg.doAdd ? (ND_width(n) / 2.0 + X_marg.x) : (ND_width(n) * X_marg.x / 2.0);
+}
+
+static double HT2(Agnode_t *n) {
+  return X_marg.doAdd ? (ND_height(n) / 2.0 + X_marg.y) : (ND_height(n) * X_marg.y / 2.0);
+}
 
 #ifdef DEBUG
 static void pr2graphs(Agraph_t *g0, Agraph_t *g1) {
@@ -72,8 +65,7 @@ static double RAD(Agnode_t * n)
 /* xinit_params:
  * Initialize local parameters
  */
-static void xinit_params(graph_t* g, int n, xparams * xpms)
-{
+static double xinit_params(graph_t *g, int n, xparams *xpms) {
     (void)g;
 
     xParams.K = xpms->K;
@@ -82,7 +74,7 @@ static void xinit_params(graph_t* g, int n, xparams * xpms)
     xParams.loopcnt = xpms->loopcnt;
     if (xpms->C > 0.0)
 	xParams.C = xpms->C;
-    K2 = xParams.K * xParams.K;
+    const double K2 = xParams.K * xParams.K;
     if (xParams.T0 == 0.0)
 	xParams.T0 = xParams.K * sqrt(n) / 5;
 #ifdef DEBUG
@@ -95,6 +87,7 @@ static void xinit_params(graph_t* g, int n, xparams * xpms)
 		xParams.C);
     }
 #endif
+    return K2;
 }
 
 #define X_T0         xParams.T0
@@ -109,125 +102,14 @@ static double cool(int t)
     return X_T0 * (X_numIters - t) / X_numIters;
 }
 
-#define EPSILON 0.01
-
-#ifdef MS
-/* dist:
- * Distance between two points
- */
-static double dist(pointf p, pointf q)
-{
-    double dx, dy;
-
-    dx = p.x - q.x;
-    dy = p.y - q.y;
-    return hypot(dx, dy);
-}
-
-/* bBox:
- * Compute bounding box of point
- */
-static void bBox(node_t * p, pointf * ll, pointf * ur)
-{
-    double w2 = WD2(p);
-    double h2 = HT2(p);
-
-    ur->x = ND_pos(p)[0] + w2;
-    ur->y = ND_pos(p)[1] + h2;
-    ll->x = ND_pos(p)[0] - w2;
-    ll->y = ND_pos(p)[1] - h2;
-}
-
-/* boxDist:
- * Return the distance between two boxes; 0 if they overlap
- */
-static double boxDist(node_t * p, node_t * q)
-{
-    pointf p_ll, p_ur;
-    pointf q_ll, q_ur;
-
-    bBox(p, &p_ll, &p_ur);
-    bBox(q, &q_ll, &q_ur);
-
-    if (q_ll.x > p_ur.x) {
-	if (q_ll.y > p_ur.y) {
-	    return dist(p_ur, q_ll);
-	} else if (q_ll.y >= p_ll.y) {
-	    return q_ll.x - p_ur.x;
-	} else {
-	    if (q_ur.y >= p_ll.y)
-		return q_ll.x - p_ur.x;
-	    else {
-		p_ur.y = p_ll.y;	/* p_ur is now lower right */
-		q_ll.y = q_ur.y;	/* q_ll is now upper left */
-		return dist(p_ur, q_ll);
-	    }
-	}
-    } else if (q_ll.x >= p_ll.x) {
-	if (q_ll.y > p_ur.y) {
-	    return q_ll.y - p_ur.x;
-	} else if (q_ll.y >= p_ll.y) {
-	    return 0.0;
-	} else {
-	    if (q_ur.y >= p_ll.y)
-		return 0.0;
-	    else
-		return p_ll.y - q_ur.y;
-	}
-    } else {
-	if (q_ll.y > p_ur.y) {
-	    if (q_ur.x >= p_ll.x)
-		return q_ll.y - p_ur.y;
-	    else {
-		p_ur.x = p_ll.x;	/* p_ur is now upper left */
-		q_ll.x = q_ur.x;	/* q_ll is now lower right */
-		return dist(p_ur, q_ll);
-	    }
-	} else if (q_ll.y >= p_ll.y) {
-	    if (q_ur.x >= p_ll.x)
-		return 0.0;
-	    else
-		return p_ll.x - q_ur.x;
-	} else {
-	    if (q_ur.x >= p_ll.x) {
-		if (q_ur.y >= p_ll.y)
-		    return 0.0;
-		else
-		    return p_ll.y - q_ur.y;
-	    } else {
-		if (q_ur.y >= p_ll.y)
-		    return p_ll.x - q_ur.x;
-		else
-		    return dist(p_ll, q_ur);
-	    }
-	}
-    }
-}
-#endif				/* MS */
-
 /* overlap:
  * Return true if nodes overlap
  */
 static int overlap(node_t * p, node_t * q)
 {
-#if defined(BOX)
-    double xdelta, ydelta;
-    int    ret;
-
-    xdelta = fabs(ND_pos(q)[0] - ND_pos(p)[0]);
-    ydelta = fabs(ND_pos(q)[1] - ND_pos(p)[1]);
-    ret = xdelta <= WD2(p) + WD2(q) && ydelta <= HT2(p) + HT2(q);
-    return ret;
-#else
-    double dist2, xdelta, ydelta;
-    double din;
-
-    din = RAD(p) + RAD(q);
-    xdelta = ND_pos(q)[0] - ND_pos(p)[0];
-    ydelta = ND_pos(q)[1] - ND_pos(p)[1];
-    dist2 = xdelta * xdelta + ydelta * ydelta;
-    return dist2 <= din * din;
-#endif
+    const double xdelta = fabs(ND_pos(q)[0] - ND_pos(p)[0]);
+    const double ydelta = fabs(ND_pos(q)[1] - ND_pos(p)[1]);
+    return xdelta <= WD2(p) + WD2(q) && ydelta <= HT2(p) + HT2(q);
 }
 
 /* cntOverlaps:
@@ -235,12 +117,10 @@ static int overlap(node_t * p, node_t * q)
  */
 static int cntOverlaps(graph_t * g)
 {
-    node_t *p;
-    node_t *q;
     int cnt = 0;
 
-    for (p = agfstnode(g); p; p = agnxtnode(g, p)) {
-	for (q = agnxtnode(g, p); q; q = agnxtnode(g, q)) {
+    for (node_t *p = agfstnode(g); p; p = agnxtnode(g, p)) {
+	for (node_t *q = agnxtnode(g, p); q; q = agnxtnode(g, q)) {
 	    cnt += overlap(p, q);
 	}
     }
@@ -250,52 +130,24 @@ static int cntOverlaps(graph_t * g)
 /* doRep:
  * Return 1 if nodes overlap
  */
-static int
-doRep(node_t * p, node_t * q, double xdelta, double ydelta, double dist2)
-{
+static int doRep(node_t *p, node_t *q, double xdelta, double ydelta,
+                 double dist2, double X_ov, double X_nonov) {
     int ov;
     double force;
-#if defined(DEBUG) || defined(MS) || defined(ALT)
-    double dist;
-#endif
 
     while (dist2 == 0.0) {
 	xdelta = 5 - rand() % 10;
 	ydelta = 5 - rand() % 10;
 	dist2 = xdelta * xdelta + ydelta * ydelta;
     }
-#if defined(MS)
-    dout = fmax(boxDist(p, q), EPSILON);
-    dist = sqrt(dist2);
-    force = K2 / (dout * dist);
-#elif defined(ALT)
-    force = K2 / dist2;
-    dist = sqrt(dist2);
-    din = RAD(p) + RAD(q);
-    if (ov = overlap(p, q)) {
-	factor = X_C;
-    } else {
-	ov = 0;
-	if (dist <= din + X_K)
-	    factor = X_C * (X_K - (dist - din)) / X_K;
-	else
-	    factor = 0.0;
-    }
-    force *= factor;
-#elif defined(ORIG)
-    force = K2 / dist2;
-    if ((ov = overlap(p, q)))
-	force *= X_C;
-#else
     if ((ov = overlap(p, q)))
 	force = X_ov / dist2;
     else
 	force = X_nonov / dist2;
-#endif
 #ifdef DEBUG
     if (Verbose == 4) {
 	prIndent();
-	dist = sqrt(dist2);
+	const double dist = sqrt(dist2);
 	fprintf(stderr, " ov Fr %f dist %f\n", force * dist, dist);
     }
 #endif
@@ -310,41 +162,15 @@ doRep(node_t * p, node_t * q, double xdelta, double ydelta, double dist2)
  * Repulsive force = (K*K)/d
  * Return 1 if nodes overlap
  */
-static int applyRep(Agnode_t * p, Agnode_t * q)
-{
-    double xdelta, ydelta;
-
-    xdelta = ND_pos(q)[0] - ND_pos(p)[0];
-    ydelta = ND_pos(q)[1] - ND_pos(p)[1];
-    return doRep(p, q, xdelta, ydelta, xdelta * xdelta + ydelta * ydelta);
+static int applyRep(Agnode_t *p, Agnode_t *q, double X_ov, double X_nonov) {
+    const double xdelta = ND_pos(q)[0] - ND_pos(p)[0];
+    const double ydelta = ND_pos(q)[1] - ND_pos(p)[1];
+    return doRep(p, q, xdelta, ydelta, xdelta * xdelta + ydelta * ydelta, X_ov,
+                 X_nonov);
 }
 
 static void applyAttr(Agnode_t * p, Agnode_t * q)
 {
-    double xdelta, ydelta;
-    double force;
-    double dist;
-    double dout;
-    double din;
-
-#if defined(MS)
-    dout = boxDist(p, q);
-    if (dout == 0.0)
-	return;
-    xdelta = ND_pos(q)[0] - ND_pos(p)[0];
-    ydelta = ND_pos(q)[1] - ND_pos(p)[1];
-    dist = hypot(xdelta, ydelta);
-    force = (dout * dout) / (X_K * dist);
-#elif defined(ALT)
-    xdelta = ND_pos(q)[0] - ND_pos(p)[0];
-    ydelta = ND_pos(q)[1] - ND_pos(p)[1];
-    dist = hypot(xdelta, ydelta);
-    din = RAD(p) + RAD(q);
-    if (dist < X_K + din)
-	return;
-    dout = dist - din;
-    force = dout * dout / ((X_K + din) * dist);
-#else
     if (overlap(p, q)) {
 #ifdef DEBUG
 	if (Verbose == 4) {
@@ -354,13 +180,12 @@ static void applyAttr(Agnode_t * p, Agnode_t * q)
 #endif
 	return;
     }
-    xdelta = ND_pos(q)[0] - ND_pos(p)[0];
-    ydelta = ND_pos(q)[1] - ND_pos(p)[1];
-    dist = hypot(xdelta, ydelta);
-    din = RAD(p) + RAD(q);
-    dout = dist - din;
-    force = dout * dout / ((X_K + din) * dist);
-#endif
+    const double xdelta = ND_pos(q)[0] - ND_pos(p)[0];
+    const double ydelta = ND_pos(q)[1] - ND_pos(p)[1];
+    const double dist = hypot(xdelta, ydelta);
+    const double din = RAD(p) + RAD(q);
+    const double dout = dist - din;
+    const double force = dout * dout / ((X_K + din) * dist);
 #ifdef DEBUG
     if (Verbose == 4) {
 	prIndent();
@@ -377,15 +202,7 @@ static void applyAttr(Agnode_t * p, Agnode_t * q)
  * Return 0 if definitely no overlaps.
  * Return non-zero if we had overlaps before most recent move.
  */
-static int adjust(Agraph_t * g, double temp)
-{
-    Agnode_t *n;
-    Agnode_t *n1;
-    Agedge_t *e;
-    double temp2;
-    double len;
-    double len2;
-    double disp[NDIM];		/* incremental displacement */
+static int adjust(Agraph_t *g, double temp, double X_ov, double X_nonov) {
     int overlaps = 0;
 
 #ifdef DEBUG
@@ -393,37 +210,36 @@ static int adjust(Agraph_t * g, double temp)
 	fprintf(stderr, "=================\n");
 #endif
 
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    for (Agnode_t *n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	DISP(n)[0] = DISP(n)[1] = 0;
     }
 
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    for (Agnode_t *n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	int ov;
-	for (n1 = agnxtnode(g, n); n1; n1 = agnxtnode(g, n1)) {
-	    ov = applyRep(n, n1);
+	for (Agnode_t *n1 = agnxtnode(g, n); n1; n1 = agnxtnode(g, n1)) {
+	    ov = applyRep(n, n1, X_ov, X_nonov);
 	    overlaps += ov;
 	}
-	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
+	for (Agedge_t *e = agfstout(g, n); e; e = agnxtout(g, e)) {
 	    applyAttr(n,aghead(e));
 	}
     }
     if (overlaps == 0)
 	return 0;
 
-    temp2 = temp * temp;
-    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+    const double temp2 = temp * temp;
+    for (Agnode_t *n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (ND_pinned(n) == P_PIN)
 	    continue;
-	disp[0] = DISP(n)[0];
-	disp[1] = DISP(n)[1];
-	len2 = disp[0] * disp[0] + disp[1] * disp[1];
+	const double disp[] = {DISP(n)[0], DISP(n)[1]}; // incremental displacement
+	const double len2 = disp[0] * disp[0] + disp[1] * disp[1];
 
 	if (len2 < temp2) {
 	    ND_pos(n)[0] += disp[0];
 	    ND_pos(n)[1] += disp[1];
 	} else {
 	    /* to avoid sqrt, consider abs(x) + abs(y) */
-	    len = sqrt(len2);
+	    const double len = sqrt(len2);
 	    ND_pos(n)[0] += disp[0] * temp / len;
 	    ND_pos(n)[1] += disp[1] * temp / len;
 	}
@@ -445,31 +261,24 @@ static int adjust(Agraph_t * g, double temp)
  */
 static int x_layout(graph_t * g, xparams * pxpms, int tries)
 {
-    int i;
-    int try;
-    int ov;
-    double temp;
     int nnodes = agnnodes(g);
     int nedges = agnedges(g);
-    double K;
-    xparams xpms;
 
     X_marg = sepFactor (g);
     if (X_marg.doAdd) {
 	X_marg.x = PS2INCH(X_marg.x); /* sepFactor is in points */
 	X_marg.y = PS2INCH(X_marg.y);
     }
-    ov = cntOverlaps(g);
+    int ov = cntOverlaps(g);
     if (ov == 0)
 	return 0;
 
-    try = 0;
-    xpms = *pxpms;
-    K = xpms.K;
-    while (ov && try < tries) {
-	xinit_params(g, nnodes, &xpms);
-	X_ov = X_C * K2;
-	X_nonov = nedges*X_ov*2.0/(nnodes*(nnodes-1));
+    xparams xpms = *pxpms;
+    const double K = xpms.K;
+    for (int try = 0; ov && try < tries; ++try) {
+	const double K2 = xinit_params(g, nnodes, &xpms);
+	const double X_ov = X_C * K2;
+	const double X_nonov = nedges * X_ov * 2.0 / (nnodes * (nnodes - 1));
 #ifdef DEBUG
 	if (Verbose) {
 	    prIndent();
@@ -479,15 +288,14 @@ static int x_layout(graph_t * g, xparams * pxpms, int tries)
 	}
 #endif
 
-	for (i = 0; i < X_loopcnt; i++) {
-	    temp = cool(i);
+	for (int i = 0; i < X_loopcnt; i++) {
+	    const double temp = cool(i);
 	    if (temp <= 0.0)
 		break;
-	    ov = adjust(g, temp);
+	    ov = adjust(g, temp, X_ov, X_nonov);
 	    if (ov == 0)
 		break;
 	}
-	try++;
 	xpms.K += K;		/* increase distance */
     }
 #ifdef DEBUG
@@ -530,7 +338,7 @@ void fdp_xLayout(graph_t * g, xparams * xpms)
 	ovlp = DFLT_overlap;
     }
     /* look for optional ":" or "number:" */
-    if ((cp = strchr(ovlp, ':')) && (cp == ovlp || isdigit((int)*ovlp))) {
+    if ((cp = strchr(ovlp, ':')) && (cp == ovlp || gv_isdigit(*ovlp))) {
       cp++;
       rest = cp;
       tries = atoi (ovlp);
